
config more[off]
config warning[off]
spool file[p_hww01.out]


# PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)
# FACULTY:		Dan McFadden
# AUTHOR:		Peter Adams
# LAST UPDATE:		February 05, 2003
# PROGRAM DESC:		Set Variables and Macros

load file[~/tmp/hww123]

# ====================================================================
# DATA PREPARATION
# ====================================================================

range obs[1-6489]

set one = 1
set zero = 0

set m12=month12
set m23=month23

set cogimp1=cogim1
set cogimp2=cogim2
set cogimp3=cogim3

set d_hous1=dnhous1
set d_hous2=dnhous2
set d_hous3=dnhous3

set ndx12=obsno
set ndx23=obsno+6489

set logm12=log(m12)
set logm23=log(m23)

# ====================================================================
# SET HEALTH CONDITION MACROS (PREVALENCE)
# ====================================================================

# SPECIFIC CONDITIONS
# --------------------------------------------------------------------
	macro cancer { cancer1 cancer2 cancer3 }
	macro heart { heart1 heart2 heart3 }
	macro stroke { stroke1 stroke2 stroke3 }
	macro lung { lung1 lung2 lung3 }
	macro diabet { diabet1 diabet2 diabet3 }
	macro highbp { highbp1 highbp2 highbp3 }
	macro arthrt { arthrt1 arthrt2 arthrt3 }
	macro incont { incont1 incont2 incont3 }
	macro fall { fall1 fall2 fall3 }
	macro hipfrc { hipfrc1 hipfrc2 hipfrc3 }
	macro proxy { proxyw1 proxyw2 proxyw3 }
	macro cogim { cogim1 cogim2 cogim3 }
	macro psych { psych1 psych2 psych3 }
	macro depres { depres1 depres2 depres3 }
	macro bmi { bmi1 bmi2 bmi3 }
	macro smoknow { smoknow1 smoknow2 smoknow3 }
	macro hibmi { hibmi1 hibmi2 hibmi2 }
	macro lobmi { lobmi1 lobmi2 lobmi2 }
	macro numadl { numadl1 numadl2 numadl3 }
	macro numiadl { numiadl1 numiadl2 numiadl3 }
	macro dhlth { dhlth1 dhlth2 dhlth3 }
	
# WAVE 1 GROUP CONDITIONS
# --------------------------------------------------------------------
	macro accute1 { cancer1 heart1 stroke1 }
	macro degenr1 { lung1 diabet1 }
	macro kron1 { highbp1 arthrt1 incont1 }
	macro accid1 { fall1 hipfrc1 }
	macro mental1 { cogim1 psych1 depres1 }

	macro cond1 { @accute1 @degenr1 @kron1 @accid1 proxyw1 \
		@mental1 bmi1 smoknow1 numadl1 numiadl1 dhlth1 }

# WAVE 2 GROUP CONDITIONS
# --------------------------------------------------------------------
	macro accute2 { cancer2 heart2 stroke2 }
	macro degenr2 { lung2 diabet2 }
	macro kron2 { highbp2 arthrt2 incont2 }
	macro accid2 { fall2 hipfrc2 }
	macro mental2 { cogim2 psych2 depres2 }

	macro cond2 { @accute2 @degenr2 @kron2 @accid2 proxyw2 \
		@mental2 bmi2 smoknow2 numadl2 numiadl2 dhlth2 }

# WAVE 3 GROUP CONDITIONS
# --------------------------------------------------------------------
	macro accute3 { cancer3 heart3 stroke3 }
	macro degenr3 { lung3 diabet3 }
	macro kron3 { highbp3 arthrt3 incont3 }
	macro accid3 { fall3 hipfrc3 }
	macro mental3 { cogim3 psych3 depres3 }

	macro cond3 { @accute3 @degenr3 @kron3 @accid3 proxyw3 \
		@mental3 bmi3 smoknow3 numadl3 numiadl3 dhlth3 }


# ====================================================================
# SET HEALTH CONDITION MACROS (INCIDENCE)
# ====================================================================

# SPECIFIC CONDITIONS
# --------------------------------------------------------------------
	macro jcancer { jcancer3 jcancer2 }
	macro jheart { jheart3 jheart2 }
	macro jstroke { jstroke3 jstroke2 }
	macro mort { tdied3 tdied2 }
	macro ilung { ilung3 ilung2 }
	macro idiabet { idiabet3 idiabet2 }
	macro ihighbp { ihighbp3 ihighbp2 }
	macro iarthrt { iarthrt3 iarthrt2 }
	macro jincont { jincont3 jincont2 }
	macro jfall { jfall3 jfall2 }
	macro jhipfrc { jhipfrc3 jhipfrc2 }
	macro icogim { icogim3 icogim2 }
	macro ipsych { ipsych3 ipsych2 }
	macro idepres { idepres3 idepres2 }
	macro bmibt { bmibt3 bmibt2 }
	macro bmiws { bmiws3 bmiws2 }
	
# WAVE 1-2 GROUP CONDITIONS
# --------------------------------------------------------------------
	macro iaccute2 { jcancer2 jheart2 jstroke2 }
	macro idegenr2 { ilung2 idiabet2 }
	macro ikron2 { ihighbp2 iarthrt2 jincont2 }
	macro iaccid2 { jfall2 jhipfrc2 }
	macro imental2 { icogim2 ipsych2 idepres2 }

	macro icond2 { @iaccute2 tdied2 @idegenr2 @ikron2 @iaccid2 \
		proxyw2 @imental2 bmibt2 bmiws2 smoknow2 \
		numadl2 numiadl2 dhlth2 }

# WAVE 2-3 GROUP CONDITIONS
# --------------------------------------------------------------------
	macro iaccute3 { jcancer3 jheart3 jstroke3 }
	macro idegenr3 { ilung3 idiabet3 }
	macro ikron3 { ihighbp3 iarthrt3 jincont3 }
	macro iaccid3 { jfall3 jhipfrc3 }
	macro imental3 { icogim3 ipsych3 idepres3 }

	macro icond3 { @iaccute3 tdied3 @idegenr3 @ikron3 @iaccid3 \
		proxyw3 @imental3 bmibt3 bmiws3 smoknow3 \
		numadl3 numiadl3 dhlth3 }


# ====================================================================
# DATA FREQUENCIES AND TABLES
# ====================================================================

list
cova var[*] byvar


save file[hww123]
spool off
quit
