
% PROJECT:		Healthy, Wealthy, & Wise (AHEAD Data)
% FACULTY:		Daniel McFadden
% AUTHOR:		Peter Adams
% LAST UPDATE:		February 13, 2003
% PROGRAM DESC:		Initialize Data (3)


% ===========================================================================
% ORIGINAL DATA MATRIX VARIABLE ORDER	[data7074]
% ===========================================================================

% one(1) as70m1(2) as80m1(3) q1wb1(4) q4wb1(5) q1ib1(6) q4ib1(7) hs(8)
% coll(9) hoodpf(10) condpf(11) nevmarr1(12) widow1(13) divsep1(14) 
% magedie1(15) pagedie1(16) smokev(17)

% hhid(18) n2hhidw1(19) male(20) female(21) agem1(22) married1(23)
% single1(24) c_2w1(25) c_2l1(26) c_2n1(27) c_2i1(28) q_2wb1(29) q_2ib1(30)
% wlth1(31) inc1(32) dnhous1(33)

% spas701(34) spas801(35) s_hs(36) s_coll(37) smagedi1(38) spagedi1(39)
% smokev(40) sagem1(41)


% ===========================================================================
% SET ORIGINAL DATA MATRICES
% ===========================================================================

   % ------------------------------------------------------------------------
   % SET RESPONDENT DATA MATRIX		[r_data]
   % ------------------------------------------------------------------------
   
   r_data=data7074(:,1:33);
   
   % ------------------------------------------------------------------------
   % SET SPOUSE DATA MATRIX		[s_data]
   % ------------------------------------------------------------------------
   
   s_data=[data7074(:,1) data7074(:,34:35) data7074(:,4:7) ...
         data7074(:,36:37) data7074(:,10:14) data7074(:,38:40) ...
         data7074(:,18:19) data7074(:,21) data7074(:,20) data7074(:,41) ...
         data7074(:,23:33)];
   
   
% ===========================================================================
% REPLICATE ORIGINAL DATA MATRICES		[r_XX, s_XX]
% ===========================================================================

r_XX=repmat(r_data,10,1);
s_XX=repmat(s_data,10,1);

   % ------------------------------------------------------------------------
   % SET COLUMN/ROW LOCATIONS
   % ------------------------------------------------------------------------
   
   col_exog=[1:17];
   col_oth=[18:33];
   
   col_n2hhidw1=19;
   col_male=20;
   col_female=21;
   col_age=22;
   col_married=23;
   col_wealth=25;
   col_liquid=26;
   col_nonliq=27;
   col_income=28;
   
   c_row=find(r_XX(:,col_married)==1);	%couple hhold (married1==1) rows
   s_row=find(r_XX(:,col_married)==0);	%single hhold (married1==0) rows
   r_row=find(r_XX(:,1)==1);		%respondent rows = c_row + s_row
   
   % ------------------------------------------------------------------------
   % SET ORIGINAL DATA VARIABLES
   % ------------------------------------------------------------------------
   
   r_as701=r_XX(:,2);
   s_as701=s_XX(:,2);
   
   r_as801=r_XX(:,3);
   s_as801=s_XX(:,3);
   
   r_male=r_XX(:,20);
   s_male=s_XX(:,20);
   r_female=r_XX(:,21);
   s_female=s_XX(:,21);
   
   r_married1=r_XX(:,23);
   s_married1=s_XX(:,23);
   
   r_dnhous1=r_XX(:,33);
   s_dnhous1=s_XX(:,33);
   
   
% ===========================================================================
% SET STACKED DATA MATRIX		[XX]
% ===========================================================================

XX=[r_XX; s_XX(c_row,:)];

NOBS=size(XX,1);
sp_row=find(r_XX(c_row,1)==1)+size(r_XX,1);	%spouse var rows

   % ------------------------------------------------------------------------
   % SET STACKED DATA VARIABLES
   % ------------------------------------------------------------------------
   
   one=XX(:,1);
   male=XX(:,col_male);
   female=XX(:,col_female);
   married1=XX(:,col_married);
   agem1=XX(:,col_age);
   c_2w1=XX(:,col_wealth);
   c_2l1=XX(:,col_liquid);
   c_2n1=XX(:,col_nonliq);
   c_2i1=XX(:,col_income);
   

% ===========================================================================
% INITIALIZE VARIABLES
% ===========================================================================

   % ------------------------------------------------------------------------
   % PREVALENCE SIMULATION: prevsim.m
   % ------------------------------------------------------------------------
   
   % If the prevalence models have been re-estimated, you need to update the
   % Standard Error for BODY MASS INDEX (BMI).
   
   psigma_f=4.48846935;
   psigma_m=3.51964781;
   
   VALID_f=find(male==0);
   VALID_m=find(male==1);
   
   check1{1,1}(1,1)=NOBS;
   check1{2,1}(1,1)=size(VALID_f,1);
   check1{3,1}(1,1)=size(VALID_m,1);
   check2{1,1}(1,1)=1;
   check2{2,1}(1,1)=1;
   check2{3,1}(1,1)=1;
   
   % ------------------------------------------------------------------------
   % INCIDENCE SIMULATION: incsim.m
   % ------------------------------------------------------------------------
   
   % If the incidence models have been re-estimated, you need to update the
   % Standard Error for BODY MASS INDEX (BMI).
   
   isigma_f=1.87645786;
   isigma_m=1.62281340;
   
   month1=25.5;
   month2=12;
   delta=12/month1;
   gamma=1/delta;
   logm1=ones(NOBS,1)*log(month1);
   logm2=ones(NOBS,1)*log(month2);
   mort1=zeros(NOBS,1);
   mort2=zeros(NOBS,1);
   
   % ------------------------------------------------------------------------
   % WEALTH/INCOME SIMULATION: wlthsim.m
   % ------------------------------------------------------------------------
   
   r_mort2=zeros(size(r_XX,1),1);
   s_mort2=zeros(size(s_XX,1),1);
   
   % GET THESE VALUES FROM p_hww06.out

   medW=87276.4688;		% among Total Sample
   medWL=7782.06543;		% among Total Sample
   medWN=60017.1484;		% among Total Sample
   medN=16368.3125;		% among Total Sample
   
   iqrW=181186.99316;		% among Total Sample
   iqrWL=56395.3663;		% among Total Sample
   iqrWN=118430.939;		% among Total Sample
   iqrN=19667.9707;		% among Total Sample
   
   cW=1/iqrW;
   cWL=1/iqrWL;
   cWN=1/iqrWN;
   cN=1/iqrN;
   
   dW=medW/iqrW;
   dWL=medWL/iqrWL;
   dWN=medWN/iqrWN;
   dN=medN/iqrN;
   
	% *******************************************************************
	% Z-VARIABLE, WAVE 1 QUARTILE THRESHOLDS (WEALTH,INCOME)
	% *******************************************************************
      
	% [married,q1 married,q3; single,q1 single,q3]
	
	% GET THESE VALUES FROM p_hww06.out
	
         q_zW1=[0.46821 0.80143; 0.38725 0.57945];
         q_zN1=[0.48935 0.74810; 0.38612 0.52707];

	%q_zW1=[.46168 .76175; .38685 .54972]; old
	%q_zN1=[.49113 .74860; .38371 .51408]; old
      
	% *******************************************************************
	% TRANSFORM WEALTH/INCOME
	% *******************************************************************

	WL1=cWL*c_2l1-dWL;		%normalized Liquid Wealth
	WN1=cWN*c_2n1-dWN;		%normalized Non-Liquid Wealth
 	N1=cN*c_2i1-dN;			%normalized Income
      
 	zWL1=1./(1+exp(-WL1));		%logistic Liquid Wealth	
 	zWN1=1./(1+exp(-WN1));		%logistic Non-Liquid Wealth
	zN1=1./(1+exp(-N1));		%logistic Income
      
	WL0=WL1;
	WN0=WN1;
	N0=N1;
      
   
% =============================================================================
% SAVE DATABASE
% =============================================================================

save exogdata.mat;








