
config more[off]
spool file[p_hww22.out]


# PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)
# FACULTY:		Dan McFadden
# AUTHOR:		Peter Adams
# LAST UPDATE:		February 07, 2003
# PROGRAM DESC:		Outfile Prevalence Coeffs (White Females: w1)


load file[~/padams/hww/probit/hww123]


# ====================================================================
# DEFINE INDEPENDENT VARIABLE MACROS
# ====================================================================

# AGE
# --------------------------------------------------------------------

macro p_age1 { as701, as801 }

# DEMOGRAPHICS
# --------------------------------------------------------------------

macro p_dem1 { nevmarr1, widow1, divsep1, magedie1, pagedie1, \
	smokev }

# SOCIO-ECONOMIC STATUS
# --------------------------------------------------------------------

macro p_ses1 { q1wb1, q4wb1, q1ib1, q4ib1, hs, coll, \
	hoodpf1, condpf1 }

# HEALTH CONDITIONS
# --------------------------------------------------------------------

macro p_canc1 { one, @p_age1, @p_ses1, @p_dem1 }

macro p_heart1 { @p_canc1, cancer1 }

macro p_strk1 { @p_heart1, heart1 }

macro p_lung1 { @p_strk1, stroke1 }

macro p_diab1 { @p_lung1, lung1 }

macro p_high1 { @p_diab1, diabet1 }

macro p_arth1 { @p_high1, highbp1 }

macro p_incon1 { @p_arth1, arthrt1 }

macro p_fall1 { @p_incon1, incont1 }

macro p_hip1 { @p_fall1, fall1 }

macro p_prox1 { @p_hip1, hipfrc1 }

macro p_cog1 { @p_prox1, proxyw1 }

macro p_psych1 { @p_cog1, cogim1 }

macro p_depr1 { @p_psych1, psych1 }

macro p_bmi1 { @p_depr1, depres1 }

macro p_smok1 { @p_bmi1, bmi1 }

macro p_adl1 { @p_smok1, smoknow1 }

macro p_iadl1 { @p_adl1, numadl1 }

macro p_hlth1 { @p_iadl1, numiadl1 }


# ====================================================================
# DEFINE DEPENDENT VARIABLE LABEL ARRAY
# ====================================================================

array a_label = ( CANCER \
	HEART \
	STROKE \
	LUNG \
	DIABETES \
	HIGH_BLOOD_PRESSURE \
	ARTHRITIS \
	INCONTINENCE \
	FALL \
	HIP_FRACTURE \
	PROXY_INTERVIEW \
	COGNITIVE_IMPAIRMENT \
	PSYCHIATRIC \
	DEPRESSION \
	BODY_MASS_INDEX \
	CURRENT_SMOKER \
	ACTIVITIES_DAILY_LIVING \
	INSTRUMENTAL_ACTIVITIES_DAILY_LIVING \
	SELF_REPORTED_HEALTH )


# ====================================================================
# COEFFICIENT LABEL ARRAY
# ====================================================================

array a_coeff = ( canc heart stroke lung diabet highbp arthrt incont \
	fall hip proxy cogim psych depres bmi smoke adl iadl dhlth )
	

# ====================================================================
# DEFINE PROBIT REGRESSION MACRO
# ====================================================================

config precis[digits=8]

macro p_prev(i,a,b) {

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.1 INCLUDE SES
echo -----------------------------------------------------------------

probit dep[a] ind[@b] \
	maxit[50] coef[b0] \
	if[(male==0)&(white==1)&(inw1==1)]

set $a_coeff[i]=var(b0)

}


# ====================================================================
# DEFINE OLS REGRESSION MACRO
# ====================================================================

config precis[digits=8]

macro r_prev(i,a,b) {

echo
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
echo i. $a_label[i] : PARAMETER ESTIMATES
echo +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

echo
echo i.1 INCLUDE SES
echo -----------------------------------------------------------------

reg dep[a] ind[@b] coef[b0] \
	if[(male==0)&(white==1)&(inw1==1)]

set $a_coeff[i]=var(b0)

}


# ====================================================================
# RUN PREVALENCE REGRESSIONS (WHITE FEMALES: WAVE 1)
# ====================================================================

# ********************************************************************
# ********************************************************************
@p_prev(1,cancer1,p_canc1)


# ********************************************************************
# ********************************************************************
@p_prev(2,heart1,p_heart1)


# ********************************************************************
# ********************************************************************
@p_prev(3,stroke1,p_strk1)


# ********************************************************************
# ********************************************************************
@p_prev(4,lung1,p_lung1)


# ********************************************************************
# ********************************************************************
@p_prev(5,diabet1,p_diab1)


# ********************************************************************
# ********************************************************************
@p_prev(6,highbp1,p_high1)


# ********************************************************************
# ********************************************************************
@p_prev(7,arthrt1,p_arth1)


# ********************************************************************
# ********************************************************************
@p_prev(8,incont1,p_incon1)


# ********************************************************************
# ********************************************************************
@p_prev(9,fall1,p_fall1)


# ********************************************************************
# ********************************************************************
@p_prev(10,hipfrc1,p_hip1)


# ********************************************************************
# ********************************************************************
@p_prev(11,proxyw1,p_prox1)


# ********************************************************************
# ********************************************************************
@p_prev(12,cogim1,p_cog1)


# ********************************************************************
# ********************************************************************
@p_prev(13,psych1,p_psych1)


# ********************************************************************
# ********************************************************************
@p_prev(14,depres1,p_depr1)


# ********************************************************************
# ********************************************************************
@r_prev(15,bmi1,p_bmi1)


# ********************************************************************
# ********************************************************************
@p_prev(16,smoknow1,p_smok1)


# ********************************************************************
# ********************************************************************
@p_prev(17,numadl1,p_adl1)


# ********************************************************************
# ********************************************************************
@p_prev(18,numiadl1,p_iadl1)


# ********************************************************************
# ********************************************************************
@p_prev(19,dhlth1,p_hlth1)


# ====================================================================
# OUTFILE COEFFICIENTS
# ====================================================================

save file[~/padams/hww/simul/rawdata/pcoeff_wf] var[canc heart \
	stroke lung diabet highbp arthrt \
	incont fall hip proxy cogim psych depres bmi smoke adl iadl \
	dhlth] dbase


spool off
quit

