
% PROJECT:		Healthy, Wealthy, & Wise (AHEAD Data)
% FACULTY:		Daniel McFadden
% AUTHOR:		Peter Adams
% LAST UPDATE:		February 10, 2003
% PROGRAM DESC:		Set Coefficient Arrays (2)


% Set the FIXED, EMPIRICAL probability of NO CONDITION (i.e. y=0) for those
% models/conditions that DID NOT converge (e.g. singular hessian or abnormal
% convergence).

ic_hip1_m=-norminv(.9216);
ic_proxy1_f=norminv(1-.1657);
ic_proxy1_m=norminv(1-.1861);


% ===========================================================================
% DEFINE PREVALENCE COEFFICIENT ARRAY
% ===========================================================================

% {1,:}=females, {2,:}=males
% ------------------------------------------------------------------------

for k=1:19;
   PC{1,k}=pc_wf(:,k)';
   PC{2,k}=pc_wm(:,k)';
end;


% ===========================================================================
% DEFINE INCIDENCE COEFFICIENT ARRAY
% ===========================================================================

% {1,:}=females, {2,:}=males, (1,:)=prev==0, (2,:)=prev==1
% ------------------------------------------------------------------------

% jcancer(1)

IC{1,1}=ic_wf(:,1:2)';
IC{2,1}=ic_wm(:,1:2)';

% jheart(2)

IC{1,2}=ic_wf(:,3:4)';
IC{2,2}=ic_wm(:,3:4)';

% jstroke(3)

IC{1,3}=ic_wf(:,5:6)';
IC{2,3}=ic_wm(:,5:6)';

% mort(4)

IC{1,4}=[ic_wf(:,7) ic_wf(:,7)]';
IC{2,4}=[ic_wm(:,7) ic_wm(:,7)]';

% ilung(5)

IC{1,5}=[ic_wf(:,8) ic_wf(:,8)]';
IC{2,5}=[ic_wm(:,8) ic_wm(:,8)]';

% idiabet(6)

IC{1,6}=[ic_wf(:,9) ic_wf(:,9)]';
IC{2,6}=[ic_wm(:,9) ic_wm(:,9)]';

% ihighbp(7)

IC{1,7}=[ic_wf(:,10) ic_wf(:,10)]';
IC{2,7}=[ic_wm(:,10) ic_wm(:,10)]';

% iarthrt(8)

IC{1,8}=[ic_wf(:,11) ic_wf(:,11)]';
IC{2,8}=[ic_wm(:,11) ic_wm(:,11)]';

% jincont(9)

IC{1,9}=ic_wf(:,12:13)';
IC{2,9}=ic_wm(:,12:13)';

% jfall(10)

IC{1,10}=ic_wf(:,14:15)';
IC{2,10}=ic_wm(:,14:15)';

% jhipfrc(11)

IC{1,11}=ic_wf(:,16:17)';
IC{2,11}=ic_wm(:,16)';
IC{2,11}(2,:)=[0 ic_hip1_m zeros(1,61)];

% proxy(12)

IC{1,12}=ic_wf(:,18)';
IC{1,12}(2,:)=[0 ic_proxy1_f zeros(1,61)];
IC{2,12}=ic_wm(:,18)';
IC{2,12}(2,:)=[0 ic_proxy1_m zeros(1,61)];

% icogim(13)

IC{1,13}=[ic_wf(:,19) ic_wf(:,19)]';
IC{2,13}=[ic_wm(:,19) ic_wm(:,19)]';

% ipsych(14)

IC{1,14}=[ic_wf(:,20) ic_wf(:,20)]';
IC{2,14}=[ic_wm(:,20) ic_wm(:,20)]';

% idepres(15)

IC{1,15}=[ic_wf(:,21) ic_wf(:,21)]';
IC{2,15}=[ic_wm(:,21) ic_wm(:,21)]';

% bmi(16)

IC{1,16}=ic_wf(:,22)';
IC{2,16}=ic_wm(:,22)';

% smoknow(17)

IC{1,17}=ic_wf(:,23:24)';
IC{2,17}=ic_wm(:,23:24)';

% numadl(18)

IC{1,18}=ic_wf(:,25)';
IC{2,18}=ic_wm(:,25)';

% numiadl(19)

IC{1,19}=ic_wf(:,26)';
IC{2,19}=ic_wm(:,26)';

% dhlth(20)

IC{1,20}=ic_wf(:,27:28)';
IC{2,20}=ic_wm(:,27:28)';


% ===========================================================================
% DEFINE WEALTH COEFFICIENT ARRAY
% ===========================================================================

% {1,:}=couple, {2,:}=spdied, {3,:}=single
% ------------------------------------------------------------------------

% all

WC{1,1}=wc_ca(:,:)';
WC{2,1}=wc_da(:,:)';
WC{3,1}=wc_sa(:,:)';

% liquid

WC{1,2}=wc_cl(:,:)';
WC{2,2}=wc_dl(:,:)';
WC{3,2}=wc_sl(:,:)';

% non-liquid

WC{1,3}=wc_cn(:,:)';
WC{2,3}=wc_dn(:,:)';
WC{3,3}=wc_sn(:,:)';


% ===========================================================================
% DEFINE INCOME COEFFICIENT ARRAY
% ===========================================================================

% {1,:}=couple, {2,:}=spdied, {3,:}=single
% ------------------------------------------------------------------------

NC{1,1}=nc_c(:,:)';
NC{2,1}=nc_d(:,:)';
NC{3,1}=nc_s(:,:)';


% ===========================================================================
% SAVE DATABASE
% ===========================================================================

clear pc_wf pc_wm ic_wf ic_wm wc_ca wc_da wc_sa wc_cl wc_dl wc_sl wc_cn ...
	wc_dn wc_sn nc_c nc_d nc_s k;

save exogdata.mat;
